@@ -2,6 +2,7 @@
 
 namespace DeepCopy\f013;
 
+use BadMethodCallException;
 use Doctrine\Persistence\Proxy;
 
 class B implements Proxy
@@ -11,15 +12,16 @@ class B implements Proxy
     /**
      * @inheritdoc
      */
-    public function __load()
+    public function __load(): void
     {
     }
 
     /**
      * @inheritdoc
      */
-    public function __isInitialized()
+    public function __isInitialized(): bool
     {
+        throw new BadMethodCallException();
     }
 
     public function getFoo()
